@@ -118,7 +118,7 @@ main(int argc, char** argv)
   if (!utCopyFileOnCache(coll, inputRep, "logoP1.cat")) goto error;
   if (!utCopyFileOnCache(coll, inputRep, "logoP2.cat")) goto error;
   
-  if (!quickScan(coll)) goto error;
+  if (!scanCollection(coll, TRUE)) goto error;
   utLog("%s", "Scan gives :", coll);
   
   utLog("%s", "try to extract the demand (2)", 0);
@@ -131,7 +131,7 @@ main(int argc, char** argv)
   if (!utCleanCaches()) goto error;
   if (!utAddFinalDemand(coll)) goto error;
   if (!utCopyFileOnCache(coll, inputRep, "logo.tar.bz2")) goto error;
-  if (!quickScan(coll)) goto error;
+  if (!scanCollection(coll, TRUE)) goto error;
   utLog("%s", "Scan before tar-bzip:", coll);
   if (!extractArchives(coll)) goto error;
   utLog("%s", "Now we have :", coll);
@@ -140,7 +140,7 @@ main(int argc, char** argv)
   /* if (!utCleanCaches()) goto error; */
   /* if (!utAddFinalDemand(coll)) goto error; */
   /* if (!utCopyFileOnCache(coll, inputRep, "logo.afio")) goto error; */
-  /* if (!quickScan(coll)) goto error; */
+  /* if (!scanCollection(coll, TRUE)) goto error; */
   /* utLog("%s", "Scan before afio:", coll); */
   /* if (!extractArchives(coll)) goto error; */
   /* utLog("%s", "Now we have :", coll); */
@@ -149,7 +149,7 @@ main(int argc, char** argv)
   if (!utCleanCaches()) goto error;
   if (!utAddFinalDemand(coll)) goto error;
   if (!utCopyFileOnCache(coll, inputRep, "logo.zip")) goto error;
-  if (!quickScan(coll)) goto error;
+  if (!scanCollection(coll, TRUE)) goto error;
   utLog("%s", "Scan before unzip:", coll);
   if (!extractArchives(coll)) goto error;
   utLog("%s", "Now we have :", coll);
@@ -159,7 +159,7 @@ main(int argc, char** argv)
   /* if (!utAddFinalDemand(coll)) goto error; */
   /* if (!utCopyFileOnCache(coll,inputRep,"logo.part1.rar")) goto error; */
   /* if (!utCopyFileOnCache(coll,inputRep,"logo.part2.rar")) goto error; */
-  /* if (!quickScan(coll)) goto error; */
+  /* if (!scanCollection(coll, TRUE)) goto error; */
   /* utLog("%s", "Scan before unrar:", coll); */
   /* if (!extractArchives(coll)) goto error; */
   /* utLog("%s", "Now we have :", coll); */
@@ -168,7 +168,7 @@ main(int argc, char** argv)
   if (!utCleanCaches()) goto error;
     if (!utAddFinalDemand(coll)) goto error;
   if (!utCopyFileOnCache(coll, inputRep, "logo.tar")) goto error;
-  if (!quickScan(coll)) goto error;
+  if (!scanCollection(coll, TRUE)) goto error;
   utLog("%s", "Scan before tar:", coll);
   if (!extractArchives(coll)) goto error;
   utLog("%s", "Now we have :", coll);
@@ -177,7 +177,7 @@ main(int argc, char** argv)
   if (!utCleanCaches()) goto error;
   if (!utAddFinalDemand(coll)) goto error;
   if (!utCopyFileOnCache(coll, inputRep, "logo.cpio.gz")) goto error;
-  if (!quickScan(coll)) goto error;
+  if (!scanCollection(coll, TRUE)) goto error;
   utLog("%s", "Scan before tar:", coll);
   if (!extractArchives(coll)) goto error;
   utLog("%s", "Now we have :", coll);
@@ -186,7 +186,7 @@ main(int argc, char** argv)
   if (!utCleanCaches()) goto error;
   if (!utAddFinalDemand(coll)) goto error;
   if (!utCopyFileOnCache(coll, inputRep, "logo.cpio.bz2")) goto error;
-  if (!quickScan(coll)) goto error;
+  if (!scanCollection(coll, TRUE)) goto error;
   utLog("%s", "Scan before tar:", coll);
   if (!extractArchives(coll)) goto error;
   utLog("%s", "Now we have :", coll);
