@@ -34,9 +34,9 @@ function UNIT_TEST_populate_datadir()
 {
     mkdir -p $MISC
 
-    for f in mediatex_cron mediatex.conf supports.txt logo \
+    for f in cron mediatex.conf supports.txt logo \
 	catalog000.txt extract000.txt servers.txt htgroup \
-	mediatex.css floppy-icon.png apache-mdtx.conf; do
+	mediatex.css floppy-icon.png apache-mdtx.conf put.sh; do
 	install -o root -g root -m 444 $srcdir/../misc/$f $MISC
     done
     for t in home index score cgi; do
@@ -49,9 +49,14 @@ function UNIT_TEST_populate_datadir()
     mkdir -p $UNIT_TEST_ROOTDIR
     chmod 755 $UNIT_TEST_ROOTDIR
 
-    mkdir -p $ETCDIR # TO MOVE !!
+    #mkdir -p $ETCDIR # TO MOVE !!
     mkdir -p $SYSCONFDIR/apache2/conf-available
     mkdir -p $SYSCONFDIR/cron.d
+    mkdir -p $SYSCONFDIR/logrotate.d/httpd-prerotate
+    mkdir -p $SYSCONFDIR/init.d
+    
+    install -o root -g root -m 444 $srcdir/../scripts/mediatexd \
+	    $SYSCONFDIR/init.d
 }
 
 # this function set the directory to use for unit tests. 
