@@ -123,7 +123,7 @@ function yourMail()
 {
     SERVER=${1-serv1}
 
-    echo "> Please, browse https://localhost/~${SERVER}-hello"
+    echo "> Please, browse https://127.0.0.1/~${SERVER}-hello"
     notice "ask for the logo file and give an email address."
     read -p "> push a key to continue"
 }
@@ -149,8 +149,28 @@ function sedInPlace()
     rm $file
 }
 
-# add init script for new server 
-# (as sytemd cannot handle a single one)
+# modify server configuration
+# $1: mdtx user (serv1 by default)
+function mdtxConfigure()
+{
+    SERVER=${1-serv1}
+    PORT=600${SERVER#serv}
+
+    # replace localhost by 127.0.0.1 in configuration
+    sedInPlace "s/\(host.*\)localhost/\1127.0.0.1/" \
+	       /etc/mediatex/$SERVER.conf
+
+    # set dedicated socket port
+    sedInPlace "s/6561/$PORT/" /etc/mediatex/$SERVER.conf
+
+    # adapt init script if used
+    if [ $DEBUG_SERVER -eq 0 ]; then
+	sed -i /etc/init.d/mediatexd-$SERVER \
+	    -e "s|--severity notice|$SEVERITY_SERVER|" \
+	    -e "s|TERM/10/KILL/5|TERM/1/KILL/5|"
+    fi
+}
+
 # $1: mdtx user (serv1 by default)
 function startInitdScript()
 {
@@ -159,33 +179,7 @@ function startInitdScript()
 
     query "start" $SERVER
     
-    # replace localhost by 127.0.0.1 in configuration
-    sedInPlace "s/\(host.*\)localhost/\1127.0.0.1/" \
-	       /etc/mediatex/$SERVER.conf
-
-    # set dedicated socket port
-    sedInPlace "s/6561/$PORT/" /etc/mediatex/$SERVER.conf
-
     if [ $DEBUG_SERVER -eq 0 ]; then
-	# copy initd script
-	sed -e "s|mediatexd|mediatexd-$SERVER|" \
-	    -e "s|\(DAEMON=/usr/bin\)/.*|\1/mediatexd|" \
-	    -e "s|mdtx|$SERVER|" \
-	    -e "s|--severity notice|$SEVERITY_SERVER|" \
-	    /etc/init.d/mediatexd > /etc/init.d/mediatexd-$SERVER
-	cat >>/etc/init.d/mediatexd-$SERVER <<EOF
-
-do_stop_cmd() {
-	start-stop-daemon --stop --quiet --retry=TERM/1/KILL/5 \
-	    \${PIDFILE:+--pidfile \${PIDFILE}} --name \$NAME --exec \$DAEMON
-	RETVAL="\$?"
-	[ "$RETVAL" = 2 ] && return 2
-	rm -f \$PIDFILE
-	return \$RETVAL
-}
-EOF
-	
-	chmod +x /etc/init.d/mediatexd-$SERVER
 	/etc/init.d/mediatexd-$SERVER start
     else 
 	cat >/tmp/doNotClose.sh <<EOF
@@ -230,7 +224,6 @@ function stopInitdScript()
     
     if [ $DEBUG_SERVER -eq 0 ]; then
 	/etc/init.d/mediatexd-$SERVER stop
-	rm -f /etc/init.d/mediatexd-$SERVER
     else
 	kill -TERM $(cat /var/run/mediatex/${SERVER}d.pid) || \
 	    rm /var/run/mediatex/${SERVER}d.pid
@@ -288,6 +281,7 @@ function cleanAll()
     topo "Clean all"
     for SERV in serv1 serv2 serv3; do
 	stopInitdScript $SERV
+	rm -fr /var/lib/mediatex/$SERV
 	mdtxA "adm purge" $SERV
     done
     rm -f /tmp/test.nb
@@ -299,13 +293,15 @@ function test1()
     if [ "x$1" != "xclean" ]; then
 	topo "Initialize"
 	mdtxA "adm init"
+	mdtxA "adm add user www-data"
+	mdtxConfigure
 	startInitdScript
 	finalQuestion "is http://localhost/~serv1/ correct ?"
     else
 	topo "Cleanup"
-	mdtxA "adm remove"
-	mdtxA "adm purge"
 	stopInitdScript
+	rm -fr /var/lib/mediatex/serv1
+	mdtxA "adm purge"
     fi
 }
 
@@ -411,7 +407,7 @@ function test5()
 	topo "Cleanup"
 	rm -fr ~serv1/cache/serv1-hello/logo*
 	rm -fr ~serv1/cache/serv1-hello/supports
-	reloadInitdScript
+	mdtxP "srv quick scan"
 	echo -n "!> you may need to re-ask for the logo file"
 	echo " and give an email address."
     fi
@@ -439,16 +435,17 @@ EOF
 	[ $TEST_OK -eq 0 ] && return
 	
 	# clean extracted files (~test5) on cache for next tests
-	topo "remove supports and extract files"
-	mdtxP "del supp iso1 from coll hello"
+	notice "remove supports and extract files"
+	#mdtxP "del supp iso1 from coll hello"
 	mdtxP "del supp /usr/share/mediatex/misc/logoP2.iso from coll hello"
-	sleep 1 # warning del supp will HUP server (so will scan cache)
 	rm -fr ~serv1/cache/serv1-hello/logo*
 	rm -fr ~serv1/cache/serv1-hello/supports
+	mdtxP "srv quick scan"
 	mdtxP "upgrade+"
     else
 	topo "Cleanup"
 	rm -fr ~serv1/cache/serv1-hello/incoming
+	mdtxP "srv quick scan"
 	sedInPlace "/(INC/, /)/ d" ~serv1-hello/git/extract000.txt
 	reloadInitdScript
     fi
@@ -461,6 +458,7 @@ function test7()
 	topo "Configure server 2 (as a private network gateway)"
 	startInitdScriptIfNeeded
 	mdtxA "adm init" serv2
+	mdtxConfigure serv2
 	sedInPlace "s/networks   www/networks   www, private/" \
 	    /etc/mediatex/serv2.conf
 	echo "Gateways private" >> /etc/mediatex/serv2.conf
@@ -471,6 +469,7 @@ function test7()
     else
 	topo "Cleanup"
 	stopInitdScript serv2
+	rm -fr /var/lib/mediatex/serv2
 	mdtxA "adm purge" serv2
     fi
 }
@@ -509,14 +508,15 @@ function test8()
     else
 	topo "Cleanup"
 
-	# remove serv2-hello keys from serv1
+	mdtxA "adm del coll hello" serv2
+	mdtxP "upgrade" serv1
+
+	# remove serv2-hello keys from serv1 (double check)
 	SRV="~serv1/git/serv1-hello/servers.txt"
 	FPS=$(grep Server $SRV | awk '{ print $2 }')
 	for FP in $FPS; do 
 	    mdtxP "del key $FP from coll hello" serv1
 	done
-	
-	mdtxA "adm del coll hello" serv2
 	restartInitdScript serv1
     fi
 }
@@ -586,13 +586,13 @@ function test10()
 	for SERV in serv1 serv2; do
 	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/logo*
 	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/supports
-	    reloadInitdScript $SERV
+	    mdtxP "srv quick scan" $SERV
 	done
 	mdtxP "srv notify" serv2
     fi
 }
 
-# Configure server 3 (from inside a private network)
+# Configure server 3 (inside a private network)
 # (close to test 7)
 function test11()
 {
@@ -600,6 +600,7 @@ function test11()
         topo "Configure server 3 (from inside a private network)"
 
 	mdtxA "adm init" serv3
+	mdtxConfigure serv3
 	sedInPlace "s/networks   www/networks   private/" \
 		   /etc/mediatex/serv3.conf
 	mdtxP "check supp ex-cd1 on /usr/share/mediatex/misc/logoP1.iso" \
@@ -609,6 +610,7 @@ function test11()
     else
 	topo "Cleanup"
 	stopInitdScript serv3
+	rm -fr /var/lib/mediatex/serv3
 	mdtxA "adm purge" serv3
     fi
 }
@@ -648,15 +650,16 @@ function test12()
     else
 	topo "Cleanup"
 
-	# remove serv3-hello keys from serv1 (but not serv2 key!)
+	mdtxA "adm del coll hello" serv3
+	mdtxP "upgrade" serv1
+
+	# remove serv3-hello keys from serv1 (double check)
 	SRV="~serv1/git/serv1-hello/servers.txt"
 	FPS1=$(grep -B3 end $SRV | grep Server | awk '{ print $2 }')
 	FPS2=$(grep -B4 6003 $SRV | grep Server | awk '{ print $2 }')
 	for FP in $FPS1 $FPS2; do 
 	    mdtxP "del key $FP from coll hello" serv1
 	done
-	
-	mdtxA "adm del coll hello" serv3
     fi
 }
 
@@ -715,10 +718,10 @@ function test14()
 	    rm -f /var/cache/mediatex/$SERV/cache/$SERV-hello/logoP2.cat
 	    rm -f /var/cache/mediatex/$SERV/cache/$SERV-hello/logo.tgz
 	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/logo
-	    reloadInitdScript $SERV
+	    mdtxP "srv quick scan" $SERV
 	done
 	rm -fr ~serv3/cache/serv3-hello/*
-	reloadInitdScript serv3
+	mdtxP "srv quick scan" serv3
     fi
 }
 
@@ -745,7 +748,7 @@ function test15()
     else
 	topo "Cleanup"
 	rm -f ~serv1/cache/serv1-hello/logo.png
-	reloadInitdScript serv1
+	mdtxP "srv quick scan" serv1
     fi
 }
 
@@ -765,8 +768,8 @@ function test16()
 	done
 
 	# move supp1 from serv2 to serv1
-	mdtxP "del supp iso1 from coll hello" serv2
-	mdtxP "add supp iso1 to coll hello" serv1
+	#mdtxP "del supp iso1 from coll hello" serv2
+	#mdtxP "add supp iso1 to coll hello" serv1
 
 	# same as test4
 	mdtxP "make" serv3
@@ -821,15 +824,13 @@ function test17()
 	mdtxP "srv save" serv3
 	finalQuestion "does serv 1 and 2 no more looking for logo.png ?" \
 	    "cat ~serv1/md5sums/serv1-hello.md5 && echo -ne '\n' \
-             && cat ~serv2/md5sums/serv2-hello.md5 && echo -ne '\n' \
-             && cat ~serv3/md5sums/serv3-hello.md5 && echo -ne '\n'"
+             && cat ~serv2/md5sums/serv2-hello.md5 && echo -ne '\n'"
     else
 	topo "Cleanup"
 	for SERV in serv1 serv2 serv3; do
-	    stopInitdScript $SERV
 	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/logo*
 	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/supports
-	    startInitdScript $SERV
+	    mdtxP "srv quick scan" $SERV
 	done
     fi	    
 }
@@ -864,9 +865,8 @@ function test19()
 
 	sedInPlace "s/\(logApache\) *\(.*\)/\1 yes/" \
 		   ~serv1-hello/git/servers.txt
-	QUERY="/etc/logrotate.d/httpd-prerotate/mediatex_logrotate"
+	QUERY="/etc/logrotate.d/httpd-prerotate/mediatex-serv1"
 	query $QUERY serv1
-	export MDTX=serv1 
 	$QUERY
 	mdtxP "make" serv1
 
@@ -938,7 +938,7 @@ function test21()
 	mdtxP "srv extract" serv1
 	mdtxP "make" serv1
 
-	finalQuestion "do you receive the audit repport ?"
+	finalQuestion "do you receive the audit repport? (mail)"
 	[ $TEST_OK -eq 0 ] && return
     else
 	topo "Cleanup"
