@@ -26,6 +26,6 @@
 BINDIR=/usr/bin
 MDTX=${MDTX-mdtx}
 
-$BINDIR/mediatex -c $MDTX -swarning -ffile srv extract    
-$BINDIR/mediatex -c $MDTX -swarning -ffile srv notify
+$BINDIR/mediatex -c $MDTX -swarning -p srv extract    
+$BINDIR/mediatex -c $MDTX -swarning -p srv notify
 
