@@ -524,7 +524,7 @@ updateMotdFromAllMd5sumsDB(Motd* motd)
 
   if (!env.noRegression) {
     // ask daemon to update md5sumsDB file
-    if (!mdtxSyncSignal(MDTX_SAVEMD5)) {
+    if (!mdtxSyncSignal(REG_SAVEMD5)) {
       logMain(LOG_WARNING, "fail to update md5sumsDB file");
     }
   }
@@ -572,10 +572,12 @@ updateMotd()
   Record* record = 0;
   char car = ':';
   int isFileToBurn = 0;
+  int isAllowed = 0;
 
   logMain(LOG_DEBUG, "updateMotd");
 
-  if (!allowedUser(env.confLabel)) goto error;
+  if (!allowedUser(env.confLabel, &isAllowed, 0)) goto error;
+  if (!isAllowed) goto error;
   if (!(conf = getConfiguration())) goto error;
   if (!loadConfiguration(CFG|SUPP)) goto error;
   if (!expandConfiguration()) goto error2;
