@@ -157,6 +157,7 @@ mdtxLsSupport()
   supports = conf->supports;
 
   rgRewind(supports);
+  if (!rgSort(supports, cmpSupport)) goto error;
   while ((supp = rgNext(supports))) {
     if (!scoreSupport(supp, &conf->scoreParam)) goto error;
   }
@@ -253,6 +254,13 @@ mdtxAddFile(char* path)
   // get the absolute path of the file
   if (!(absolutePath = getAbsolutePath(path))) goto error;
 
+  // check path do not comes from mediatex's cache
+  if (!strncmp(absolutePath, CONF_CACHEDIR, strlen(CONF_CACHEDIR))) {
+    logMain(LOG_ERR, "support file must comes from outside of "
+	    "the mediatex's cache");
+    goto error;
+  }
+
   // look for this name in the support Ring
   if (!loadConfiguration(SUPP)) goto error;
   if ((supp = getSupport(absolutePath))) {
