@@ -89,12 +89,6 @@ typedef struct Record Record;
 
 // needed by parsers so as to include scanners headers
 typedef void* yyscan_t;
-typedef struct UploadParams {
-  char* file;
-  char* catalog;
-  char* extract;
-  char* target;
-} UploadParams;
 
 // define the fundamental boolean constants
 #define TRUE 1
@@ -267,6 +261,13 @@ struct ScoreParam {
 
 // Defensive programming macros
 
+#define checkString(string, label) {				\
+    if (!string || !(*string))	{				\
+      logMisc(LOG_ERR, "please provide a %s", label);		\
+      goto error;						\
+    }								\
+  }
+
 #define checkLabel(label) {					\
     if (!label || !(*label))	{				\
       logMisc(LOG_ERR, "%s", "please provide a label");		\
