@@ -64,7 +64,7 @@ usage(char* programName)
 	  "  check supp SUPP on PATH  Provide an external support (that is accessible now).\n"
 	  "  add supp SUPP to (all|coll COLL)  Share a support with a collection.\n"
 	  "  del supp SUPP from (all|coll COLL)  Withdraw a support from a collection.\n"
-	  "  upload+{0,2} [file FILE as TARGET] [catalog FILE] [rules FILE] to coll COLL  Upload an incoming archive into the cache. Appending one or two '+' will run ``uprade'' or ``upgrade+make'' queries too.\n"
+	  "  upload+{0,2} [file FILE as TARGET]* [catalog FILE] [rules FILE] to coll COLL  Upload an incoming archive into the cache. Appending one or two '+' will run ``uprade'' or ``upgrade+make'' queries too.\n"
 	  
 	  "\nMeta-data management:\n"
 	  "  list [master] coll  List collections.\n"	  
@@ -78,7 +78,9 @@ usage(char* programName)
 	  "  audit coll COLL for MAIL  Extract all archives from a collection.\n"
 
 	  "\nQueries to daemon:\n"
-	  "  srv (save|extract|notify|deliver)  repectively ask server to dump its state into disk, perform extractions, communicate its state to other servers, deliver mails related to extracted archives (no more needed).\n"
+	  "  srv (save|extract|notify)  repectively ask server to dump its state into disk, perform extractions, communicate its state to other servers, deliver mails related to extracted archives (no more needed).\n"
+	  "  srv [quick] scan  ask server to manage file added manually to the cache. Only check file's sizes but do not compute checksums on quick scan.\n"
+	  "  srv (trim|clean|purge)  ask server remove from the cache all files that repectively can be extracted by using containers present into the cache, are safe and can be extracted locally using local supports or that are safe.\n"
 
 	  "\nInternal/debug queries:\n"
 	  "  adm (update|commit|make) [coll COLL]  Manage CVS synchronisation (already managed by ``upgrade'' query) or Build the local HTML catalogue without CVS synchronisation.\n"
@@ -125,7 +127,7 @@ main(int argc, char** argv)
   // import mdtx environment
   env.noGit = FALSE;         // enable git
   env.noGitPullPush = FALSE; // enable git to reach network
-  env.allocLimit *= 2;
+  env.allocLimit *= 4;
   env.allocDiseaseCallBack = clientDiseaseAll;
   getEnv(&env);
 
