@@ -158,7 +158,8 @@ destroyCollection(Collection* self)
   // free the locks
   for (i=iCTLG; i<iCACH; ++i) {
     if ((err = pthread_mutex_destroy(&self->mutex[i]))) {
-      logMemory(LOG_INFO, "pthread_mutex_destroy[%i]: %s", i, strerror(err));
+      logMemory(LOG_INFO, "pthread_mutex_destroy[%i]: %s", i, 
+		strerror(err));
       goto error;
     }
   }
@@ -504,6 +505,7 @@ createConfiguration(void)
   }
     
   memset(conf, 0, sizeof(Configuration));
+  conf->sem = -1;
   if ((conf->allNetworks = createRing()) == 0) goto error;
   if ((conf->networks = createRing()) == 0) goto error;
   if ((conf->gateways = createRing()) == 0) goto error;
@@ -967,7 +969,7 @@ getCollection(char *label)
 /*=======================================================================
  * Function   : addCollection
  * Description: Add a collection if not already there.
- * Synopsis   : Collection* getCollection(char* label)
+ * Synopsis   : Collection* addCollection(char* label)
  * Input      : char* label         = The catalog's label
  * Output     : The catalog's collection we have found/added
  =======================================================================*/
@@ -988,7 +990,7 @@ addCollection(char *label)
   // add new one if not already there
   if (!(coll = createCollection())) goto error;
   strncpy(coll->label, label, MAX_SIZE_COLL);
-  coll->label[MAX_SIZE_COLL] = (char)0; // developpement code 
+  coll->label[MAX_SIZE_COLL] = (char)0;
   if (!rgInsert(conf->collections, coll)) goto error;
 
  end:
