@@ -516,13 +516,13 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   120,   120,   122,   126,   131,   137,   141,   145,   149,
-     157,   162,   167,   175,   180,   185,   193,   198,   203,   211,
-     216,   221,   231,   237,   243,   249,   256,   263,   271,   277,
-     284,   293,   299,   305,   311,   318,   326,   333,   339,   349,
-     355,   363,   371,   384,   393,   401,   408,   414,   420,   426,
-     434,   440,   446,   451,   455,   459,   464,   472,   477,   481,
-     487
+       0,   120,   120,   122,   127,   132,   138,   142,   146,   150,
+     158,   163,   168,   176,   181,   186,   194,   199,   204,   212,
+     217,   222,   232,   238,   244,   250,   257,   264,   272,   278,
+     285,   294,   300,   306,   312,   319,   327,   334,   340,   350,
+     356,   364,   372,   385,   394,   402,   409,   415,   421,   427,
+     435,   441,   447,   452,   456,   460,   465,   473,   478,   482,
+     488
 };
 #endif
 
@@ -1369,371 +1369,372 @@ yyreduce:
         case 3:
 #line 122 "parser/catalogFile.y" /* yacc.c:1646  */
     {
-  logParser(LOG_WARNING, "the catalog file was empty");
+  logParser(LOG_WARNING, "the %s' catalog file was empty",
+	    coll->label);
 }
-#line 1375 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1376 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 4:
-#line 127 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 128 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "stanzas: stanzas stanza");
 }
-#line 1384 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1385 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 132 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 133 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "stanzas: stanza");
 }
-#line 1392 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1393 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 138 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 139 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "stanza: defCategory");
 }
-#line 1400 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1401 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 7:
-#line 142 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 143 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "stanza: defHuman");
 }
-#line 1408 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1409 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 8:
-#line 146 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 147 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "stanza: defDocument");
 }
-#line 1416 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1417 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 150 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 151 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "stanza: deFaRCHIVE");
 }
-#line 1424 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1425 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 158 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 159 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "cateCaracs: cateCaracs cateCarac");
 }
-#line 1433 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1434 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 163 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 164 "parser/catalogFile.y" /* yacc.c:1646  */
     {
  logParser(LOG_DEBUG, "line %i: %s", LINENO, "cateCaracs: cateCarac");
 }
-#line 1441 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1442 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 168 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 169 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   Carac* carac = 0;
   logParser(LOG_DEBUG, "line %i: cateCarac: %s = %s", LINENO, (yyvsp[-2].string), (yyvsp[0].string));
   if (!(carac = addCarac(coll, (yyvsp[-2].string)))) YYERROR;
   if (!addAssoCarac(coll, carac, CATE, category, (yyvsp[0].string))) YYERROR;
 }
-#line 1452 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1453 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 176 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 177 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "docCaracs: docCaracs docCarac");
 }
-#line 1461 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1462 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 14:
-#line 181 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 182 "parser/catalogFile.y" /* yacc.c:1646  */
     {
  logParser(LOG_DEBUG, "line %i: %s", LINENO, "docCaracs: docCarac");
 }
-#line 1469 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1470 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 186 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 187 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   Carac* carac = 0;
   logParser(LOG_DEBUG, "line %i: docCarac: %s = %s", LINENO, (yyvsp[-2].string), (yyvsp[0].string));
   if (!(carac = addCarac(coll, (yyvsp[-2].string)))) YYERROR;
   if (!addAssoCarac(coll, carac, DOC, document, (yyvsp[0].string))) YYERROR;
 }
-#line 1480 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1481 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 194 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 195 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "humCaracs: humCaracs humCarac");
 }
-#line 1489 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1490 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 17:
-#line 199 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 200 "parser/catalogFile.y" /* yacc.c:1646  */
     {
  logParser(LOG_DEBUG, "line %i: %s", LINENO, "humCaracs: humCarac");
 }
-#line 1497 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1498 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 18:
-#line 204 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 205 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   Carac* carac = 0;
   logParser(LOG_DEBUG, "line %i: humCarac: %s = %s", LINENO, (yyvsp[-2].string), (yyvsp[0].string));
   if (!(carac = addCarac(coll, (yyvsp[-2].string)))) YYERROR;
   if (!addAssoCarac(coll, carac, HUM, human, (yyvsp[0].string))) YYERROR;
 }
-#line 1508 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1509 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 19:
-#line 212 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 213 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "archCaracs: archCaracs archCarac");
 }
-#line 1517 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1518 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 20:
-#line 217 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 218 "parser/catalogFile.y" /* yacc.c:1646  */
     {
  logParser(LOG_DEBUG, "line %i: %s", LINENO, "archCaracs: archCarac");
 }
-#line 1525 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1526 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 21:
-#line 222 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 223 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   Carac* carac = 0;
   logParser(LOG_DEBUG, "line %i: archCarac: %s = %s", LINENO, (yyvsp[-2].string), (yyvsp[0].string));
   if (!(carac = addCarac(coll, (yyvsp[-2].string)))) YYERROR;
   if (!addAssoCarac(coll, carac, ARCH, archive, (yyvsp[0].string))) YYERROR;
 }
-#line 1536 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1537 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 22:
-#line 232 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 233 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "newCategory : category caracs");
   category = 0;
 }
-#line 1546 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1547 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 23:
-#line 238 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 239 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "newCategory : category");
   category = 0;
 }
-#line 1556 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1557 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 244 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 245 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "newCategory cateCaracs");
   category = 0;
 }
-#line 1566 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1567 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 25:
-#line 250 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 251 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "newCategory");
   category = 0;
 }
-#line 1575 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1576 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 26:
-#line 257 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 258 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "newCategory: TOP CATEGORY category");
   if (!((yyval.category) = addCategory(coll, (yyvsp[0].string), TRUE))) YYERROR;
   category = (yyval.category);
 }
-#line 1586 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1587 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 264 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 265 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "newCategory: CATEGORY category");
   if (!((yyval.category) = addCategory(coll, (yyvsp[0].string), FALSE))) YYERROR;
   category = (yyval.category);
 }
-#line 1597 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1598 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 28:
-#line 272 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 273 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "categories: categories , category");
   if (!addCategoryLink(coll, (yyvsp[0].category), category)) YYERROR;
 }
-#line 1607 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1608 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 29:
-#line 278 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 279 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "categories: category");
   if (!addCategoryLink(coll, (yyvsp[0].category), category)) YYERROR;
 }
-#line 1616 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1617 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 285 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 286 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: category: %s", LINENO, (yyvsp[0].string));
   if (!((yyval.category) = addCategory(coll, (yyvsp[0].string), FALSE))) YYERROR;
 }
-#line 1625 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1626 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 31:
-#line 294 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 295 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "defHuman: newHuman COLON humCategories humCaracs");
   human = 0;
 }
-#line 1635 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1636 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 300 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 301 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "defHuman: newHuman : humCategories");
   human = 0;
 }
-#line 1645 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1646 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 33:
-#line 306 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 307 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "defHuman: newHuman humCaracs");
   human = 0;
 }
-#line 1655 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1656 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 34:
-#line 312 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 313 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "defHuman: newHuman");
   human = 0;
 }
-#line 1664 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1665 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 35:
-#line 319 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 320 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "newHuman: HUMAN human");
   human = (yyvsp[0].human);
 }
-#line 1674 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1675 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 36:
-#line 327 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 328 "parser/catalogFile.y" /* yacc.c:1646  */
     {
     logParser(LOG_DEBUG, "line %i: human: %s %s", LINENO, (yyvsp[-1].string), (yyvsp[0].string));
     if (!((yyval.human) = addHuman(coll, (yyvsp[-1].string), (yyvsp[0].string)))) YYERROR;
 }
-#line 1683 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1684 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 37:
-#line 334 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 335 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO,
 	    "humCategories: humCategories , category");
   if (!addHumanToCategory(coll, human, (yyvsp[0].category))) YYERROR;
 }
-#line 1693 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1694 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 38:
-#line 340 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 341 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "humCategories: category");
   if (!addHumanToCategory(coll, human, (yyvsp[0].category))) YYERROR;
 }
-#line 1703 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1704 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 39:
-#line 350 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 351 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "defArchive: newArchive caracs");
   archive = 0;
 }
-#line 1713 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1714 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 40:
-#line 356 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 357 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "defArchive: neWArchive");
   archive = 0;
 }
-#line 1723 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1724 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 41:
-#line 364 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 365 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "newArchive: ARCHIVE archive");
   archive = (yyvsp[0].archive);
 }
-#line 1733 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1734 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 42:
-#line 372 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 373 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: archive: %s:%lli", LINENO, (yyvsp[-2].hash), (yyvsp[0].size));
   if (!((yyval.archive) = getArchive(coll, (yyvsp[-2].hash), (yyvsp[0].size)))) {
@@ -1742,175 +1743,175 @@ yyreduce:
     YYERROR;
   }
 }
-#line 1746 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1747 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 43:
-#line 385 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 386 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "defDocument: newDocument docCategories "
 	    "docWiths docCaracs docArchives");
   document = 0;
 }
-#line 1757 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1758 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 44:
-#line 394 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 395 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "newDocument: DOCUMENT document");
   document = (yyvsp[0].document);
 }
-#line 1767 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1768 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 45:
-#line 402 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 403 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: document: %s", LINENO, (yyvsp[0].string));
   if (!((yyval.document) = addDocument(coll, (yyvsp[0].string)))) YYERROR;
 }
-#line 1776 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1777 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 46:
-#line 409 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 410 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "docCategories2: : docCategories");
 }
-#line 1785 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1786 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 47:
-#line 414 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 415 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "docCategories: nil");
 }
-#line 1794 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1795 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 48:
-#line 421 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 422 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "docCategories: docCategories , category");
   if (!addDocumentToCategory(coll, document, (yyvsp[0].category))) YYERROR;
 }
-#line 1804 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1805 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 49:
-#line 427 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 428 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "docCategories: category");
   if (!addDocumentToCategory(coll, document, (yyvsp[0].category))) YYERROR;
 }
-#line 1814 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1815 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 50:
-#line 435 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 436 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "docCaracs2: docCaracs");
 }
-#line 1823 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1824 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 51:
-#line 440 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 441 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "docCaracs2: (0)");
 }
-#line 1832 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1833 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 52:
-#line 447 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 448 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "docWiths: roles");
 }
-#line 1840 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1841 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 53:
-#line 451 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 452 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "docWiths: (0)");
 }
-#line 1848 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1849 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 54:
-#line 456 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 457 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "roles: roles role");
 }
-#line 1856 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1857 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 55:
-#line 460 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 461 "parser/catalogFile.y" /* yacc.c:1646  */
     {
  logParser(LOG_DEBUG, "line %i: %s", LINENO, "roles: role");
 }
-#line 1864 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1865 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 56:
-#line 465 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 466 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   Role* role = 0;
   logParser(LOG_DEBUG, "line %i: role: WITH %s = human", LINENO, (yyvsp[-2].string));
   if (!(role = addRole(coll, (yyvsp[-2].string)))) YYERROR;
   if (!addAssoRole(coll, role, (yyvsp[0].human), document)) YYERROR;
 }
-#line 1875 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1876 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 57:
-#line 473 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 474 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: docArchives: archives", LINENO);
 }
-#line 1883 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1884 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 58:
-#line 477 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 478 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: docArchives: (0)", LINENO);
 }
-#line 1891 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1892 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 59:
-#line 482 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 483 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO,
 	    "archives: archives archive");
   if (!addArchiveToDocument(coll, (yyvsp[0].archive), document)) YYERROR;
 }
-#line 1901 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1902 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 60:
-#line 488 "parser/catalogFile.y" /* yacc.c:1646  */
+#line 489 "parser/catalogFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, "archives: archive");
  if (!addArchiveToDocument(coll, (yyvsp[0].archive), document)) YYERROR;
 }
-#line 1910 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1911 "parser/catalogFile.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1914 "parser/catalogFile.tab.c" /* yacc.c:1646  */
+#line 1915 "parser/catalogFile.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2138,7 +2139,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 493 "parser/catalogFile.y" /* yacc.c:1906  */
+#line 494 "parser/catalogFile.y" /* yacc.c:1906  */
 
 
 /* epilogue: =======================================================*/
