@@ -508,9 +508,9 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   110,   110,   112,   117,   121,   127,   135,   136,   137,
-     144,   156,   169,   173,   179,   181,   190,   194,   200,   207,
-     214
+       0,   110,   110,   112,   118,   122,   128,   136,   137,   138,
+     145,   157,   170,   174,   180,   182,   191,   195,   201,   208,
+     215
 };
 #endif
 
@@ -1306,47 +1306,48 @@ yyreduce:
         case 3:
 #line 112 "parser/extractFile.y" /* yacc.c:1646  */
     {
-  logParser(LOG_WARNING, "%s", "the extract file was empty");
+  logParser(LOG_WARNING, "the %s' extract file was empty", 
+	    coll->label);
 }
-#line 1312 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1313 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 4:
-#line 118 "parser/extractFile.y" /* yacc.c:1646  */
+#line 119 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: stanzas: stanzas stanza", LINENO);
 }
-#line 1320 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1321 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 122 "parser/extractFile.y" /* yacc.c:1646  */
+#line 123 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: stanzas: stanza", LINENO);
 }
-#line 1328 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1329 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 128 "parser/extractFile.y" /* yacc.c:1646  */
+#line 129 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "stanza: (container => childs)");
 
 }
-#line 1338 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1339 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 138 "parser/extractFile.y" /* yacc.c:1646  */
+#line 139 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: stdContainer parents", LINENO);
 }
-#line 1346 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1347 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 145 "parser/extractFile.y" /* yacc.c:1646  */
+#line 146 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: incContainer: %s", 
 	    LINENO, strEType((yyvsp[0].type)));
@@ -1357,11 +1358,11 @@ yyreduce:
   }
   container = coll->extractTree->incoming;
 }
-#line 1361 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1362 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 157 "parser/extractFile.y" /* yacc.c:1646  */
+#line 158 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: stdContainer: %s archive",
 	    LINENO, strEType((yyvsp[-1].type)));
@@ -1372,27 +1373,27 @@ yyreduce:
   }
   if (!(container = addContainer(coll, (yyvsp[-1].type), (yyvsp[0].archive)))) YYERROR;
 }
-#line 1376 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1377 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 170 "parser/extractFile.y" /* yacc.c:1646  */
+#line 171 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: parents: parents parent", LINENO);
 }
-#line 1384 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1385 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 174 "parser/extractFile.y" /* yacc.c:1646  */
+#line 175 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: parents: parent", LINENO);
 }
-#line 1392 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1393 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 181 "parser/extractFile.y" /* yacc.c:1646  */
+#line 182 "parser/extractFile.y" /* yacc.c:1646  */
     {
   if (container->type != INC) {
     logParser(LOG_ERR, "line %i: %s", LINENO, 
@@ -1400,54 +1401,54 @@ yyreduce:
     YYERROR;
   }
 }
-#line 1404 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1405 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 191 "parser/extractFile.y" /* yacc.c:1646  */
+#line 192 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: childs: childs child", LINENO);
 }
-#line 1412 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1413 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 17:
-#line 195 "parser/extractFile.y" /* yacc.c:1646  */
+#line 196 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: childs: child", LINENO);
 }
-#line 1420 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1421 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 18:
-#line 201 "parser/extractFile.y" /* yacc.c:1646  */
+#line 202 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: parent: archive", LINENO);
   if (!addFromArchive(coll, container, (yyvsp[0].archive))) YYERROR;
 }
-#line 1429 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1430 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 19:
-#line 208 "parser/extractFile.y" /* yacc.c:1646  */
+#line 209 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: child: archive %s", LINENO, (yyvsp[0].string));
   if (!(addFromAsso(coll, (yyvsp[-1].archive), container, (yyvsp[0].string)))) YYERROR;
 }
-#line 1438 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1439 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 20:
-#line 215 "parser/extractFile.y" /* yacc.c:1646  */
+#line 216 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: archive: %s:%lli", LINENO, (yyvsp[-2].hash), (yyvsp[0].size));
   if (!((yyval.archive) = addArchive(coll, (yyvsp[-2].hash), (yyvsp[0].size)))) YYERROR;
 }
-#line 1447 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1448 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1451 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1452 "parser/extractFile.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1675,7 +1676,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 221 "parser/extractFile.y" /* yacc.c:1906  */
+#line 222 "parser/extractFile.y" /* yacc.c:1906  */
 
 
 /* epilogue: =======================================================*/
