@@ -98,13 +98,16 @@ extern int shell_debug;
     shellSU = 300,
     shellMOTD = 301,
     shellAUDIT = 302,
-    shellDELIVER = 303,
-    shellSAVE = 304,
-    shellEXTRACT = 305,
-    shellNOTIFY = 306,
-    shellAROBASE = 307,
-    shellCOLON = 308,
-    shellMINUS = 309
+    shellSAVE = 303,
+    shellEXTRACT = 304,
+    shellNOTIFY = 305,
+    shellQUICK = 306,
+    shellSCAN = 307,
+    shellTRIM = 308,
+    shellSTATUS = 309,
+    shellAROBASE = 310,
+    shellCOLON = 311,
+    shellMINUS = 312
   };
 #endif
 /* Tokens.  */
@@ -153,13 +156,16 @@ extern int shell_debug;
 #define shellSU 300
 #define shellMOTD 301
 #define shellAUDIT 302
-#define shellDELIVER 303
-#define shellSAVE 304
-#define shellEXTRACT 305
-#define shellNOTIFY 306
-#define shellAROBASE 307
-#define shellCOLON 308
-#define shellMINUS 309
+#define shellSAVE 303
+#define shellEXTRACT 304
+#define shellNOTIFY 305
+#define shellQUICK 306
+#define shellSCAN 307
+#define shellTRIM 308
+#define shellSTATUS 309
+#define shellAROBASE 310
+#define shellCOLON 311
+#define shellMINUS 312
 
 /* Value type.  */
 #if ! defined SHELL_STYPE && ! defined SHELL_STYPE_IS_DECLARED
@@ -172,7 +178,7 @@ union SHELL_STYPE
   char        string[MAX_SIZE_STRING+1];
   Collection* coll;
 
-#line 176 "parser/shellQuery.tab.h" /* yacc.c:1909  */
+#line 182 "parser/shellQuery.tab.h" /* yacc.c:1909  */
 };
 # define SHELL_STYPE_IS_TRIVIAL 1
 # define SHELL_STYPE_IS_DECLARED 1
@@ -210,6 +216,6 @@ int shell_parse (yyscan_t yyscanner, Collection* coll, UploadParams* upParam);
 
 #define YYSTYPE SHELL_STYPE
 
-#line 214 "parser/shellQuery.tab.h" /* yacc.c:1909  */
+#line 220 "parser/shellQuery.tab.h" /* yacc.c:1909  */
 
 #endif /* !YY_SHELL_PARSER_SHELLQUERY_TAB_H_INCLUDED  */
